@@ -1,11 +1,12 @@
 package Apache::CGI::Builder ;
-$VERSION = 1.1 ;
+$VERSION = 1.2 ;
 
 ; use strict
 ; $Carp::Internal{+__PACKAGE__}++
-
 ; use mod_perl
 ; use constant MP2 => $mod_perl::VERSION >= 1.99
+; our $usage = qq(Apache::CGI::Builder should be used INSTEAD of CGI::Builder )
+             . qq(and should not be included as an extension)
 
 ; BEGIN
    { require File::Basename
@@ -27,6 +28,18 @@ $VERSION = 1.1 ;
       }
    }
    
+; sub import
+   { undef $usage
+   ; require CGI::Builder
+   ; unshift @_, 'CGI::Builder'
+   ; goto &CGI::Builder::import
+   }
+
+; use Class::props
+        { name       => 'no_page_content_status'
+        , default    => '404 Not Found'
+        }
+
 ; use Object::props
       ( { name     => 'r'
         , allowed  => qr/^Apache::CGI::Builder::_::process$/
@@ -51,16 +64,6 @@ $VERSION = 1.1 ;
    ; MP2 ? Apache::OK : Apache::Constants::OK
    }
 
-; sub page_content_check
-   { my $s = shift
-   ; unless (length $s->page_content)
-      { $s->header( -status => '404 Not Found' )
-            unless defined $s->header->{-status}
-      ; return 0
-      }
-   ; 1
-   }
-
 ; 1
 
 
@@ -70,7 +73,7 @@ __END__
 
 Apache::CGI::Builder - CGI::Builder and Apache/mod_perl integration
 
-=head1 VERSION 1.1
+=head1 VERSION 1.2
 
 The latest versions changes are reported in the F<Changes> file in this distribution. To have the complete list of all the extensions of the CBF, see L<CGI::Builder/"Extensions List">
 
@@ -81,7 +84,7 @@ The latest versions changes are reported in the F<Changes> file in this distribu
 =item Prerequisites
 
     Apache/mod_perl 1 or 2
-    CGI::Builder >= 1.1
+    CGI::Builder >= 1.2
 
 =item CPAN
 
@@ -104,7 +107,12 @@ From the directory where this file is located, type:
 
 =head1 SYNOPSIS
 
-   # include in your build
+   # use instead of the CGI::Builder
+   use Apache::CGI::Builder
+   qw| ... other inclusions ...
+     |;
+   
+   # deprecated way of inclusion still working
    use CGI::Builder
    qw| Apache::CGI::Builder
        ... other inclusions ...
@@ -114,30 +122,29 @@ From the directory where this file is located, type:
    $r = $self->r ;
    %headers = $self->r->headers_in ;
    
-   # virtual run mode pages
-   # instead of using this
-   http://www.yourdomain.com/cgi-bin/appScript.pl?p=aPage
+   # virtual pages: instead of using this
+   http://www.yourdomain.com/cgi-bin/IScript.cgi?p=a_page
    
    # you can use this
-   http://www.yourdomain.com/aPage
+   http://www.yourdomain.com/a_page
 
 =head1 DESCRIPTION
 
-This module is a C<CGI::Builder> extension that supply a perl handler to integrate your application modules with the Apache/mod_perl server.
+This module is a subclass of C<CGI::Builder> that supply a perl handler to integrate your CBB with the Apache/mod_perl server.
 
-Include this module in your build, if your application can take advantage from accessing the Apache request object (available as the C<r> property), and/or to run your application in a handy and alternative way. If you don't need any of the above features, you can use the C<CGI::Builder> module that is however fully mod_perl 1 and 2 compatible.
+You should use this module B<instead of CGI::Builder> if your application can take advantage from accessing the Apache request object (available as the C<r> property), and/or to run your application in a handy and alternative way. If you don't need any of the above features, you can use the C<CGI::Builder> module that is however fully mod_perl 1 and 2 compatible.
 
-B<Note>: most of the interesting reading of how organize your application module are in L<CGI::Builder>.
+B<Note>: most of the interesting reading about how to organize your application module are in L<CGI::Builder>.
 
 B<Note>: An extremely powerful combination with this extension is the L<CGI::Builder::Magic|CGI::Builder::Magic>, that can easily implement a sort of L<Perl Side Include|CGI::Builder::Magic/"Perl Side Include"> (sort of easier, more powerful and flexible "Server Side Include").
 
 =head2 No Instance Script needed
 
-A regular CGI::Builder application, uses an Instance Script to call the Application Module. With C<Apache::CGI::Builder> the Apache/mod_perl server uses the Application module directly (throug the perl handler supplied by this module), without the need of any Instance Script.
+A regular CGI::Builder application, uses an Instance Script to make an instance of the CBB. With C<Apache::CGI::Builder> the Apache/mod_perl server uses the CBB directly (throug the perl handler supplied by this module), without the need of any Instance Script.
 
 =head2 The Perl Handler
 
-This module provide a mod_perl 1 and 2 compatible handler that internally creates the Application object and produce the output page, after setting the following properties:
+This module provide a mod_perl 1 and 2 compatible handler that internally creates the CBB object and produce the output page, after setting the following properties:
 
 =over
 
@@ -163,28 +170,36 @@ B<Note>: Usually you don't need to use neither the perl handler nor these proper
 
 =head3 How to pass the page_name
 
-In a regular CBA the page_name usually comes from a query parameter or from code inside your application. Both ways are still working with this extension, but you have another way: use the base filename of your links as the page_name.
+In a regular CBA the page_name usually comes from a query parameter or from code inside your application (if you have overridden the get_page_name() method). Both ways are still working with this extension, but you have another way: use the base filename of your links as the page_name.
 
-E.g.: Providing that the RootDirectory of C<'yourdomain.com'> has been correctly configured to be handled by your Application module:
+E.g.: Providing that the RootDirectory of C<'yourdomain.com'> has been correctly configured to be handled by your CBB:
 
 Instead of using this (good for any regular CBA):
 
-    http://www.yourdomain.com/cgi-bin/IScript.pl?p=aPage
+    http://www.yourdomain.com/cgi-bin/IScript.pl?p=a_page
 
 You can use this:
 
-    http://www.yourdomain.com/aPage
+    http://www.yourdomain.com/a_page
 
 Same thing with more query parameters:
 
-    http://www.yourdomain.com/cgi-bin/IScript.pl?p=aPage&myField=aValue
-    http://www.yourdomain.com/aPage?myField=aValue
+    http://www.yourdomain.com/cgi-bin/IScript.pl?p=a_page&myField=aValue
+    http://www.yourdomain.com/a_page?myField=aValue
 
 B<Note>: Remember that this technique utilize the default page_name. Default means that it is overridable by setting explicitly the page_name inside your code, or passing an explicit 'p' query parameter. (i.e. if you want to use the provided default, you have just to avoid to set it explicitly).
 
+B<Warning>: This extension sets the C<page_name> property to the basename of the Apache filename variable, which is the result of the C<< URI -> filename >> translation. For this reason, on some systems, the C<page_name> could be not exactly the basename of the requested URI, and it could result in a string composed by all small caps characters, even if the requested URI was composed by all upper caps characters.
+
+For example this URI:
+
+    http:://www.yourdomain.com/aPage.html
+
+could generate a C<page_name> equal to 'apage' which probably does not match with your C<SH_aPage> C<PH_aPage> handlers, so in order to avoid possible problems, I would suggest the most simple and compatible solution, which is: always use all small caps for page names, templates names, page and switch handlers, URLs, ...
+
 =head2 Apache configuration
 
-The Apache configuration for mod-perl 1 or 2 is extremely simple. In order to use e.g. your F<FooBar.pm> Application module, you have to follow these steps:
+The Apache configuration for mod-perl 1 or 2 is extremely simple. In order to use e.g. your F<FooBar.pm> CBB, you have to follow these steps:
 
 =over
 
@@ -247,6 +262,20 @@ Use the Apache configuration sections C<Location>, C<Directory>, C<DirectoryMatc
 
 B<Note>: see also the F</magic_examples/perl_side_include/.htaccess> file in this distribution.
 
+=head2 Useful links
+
+=over
+
+=item *
+
+A simple and useful navigation system between the various CBF extensions is available at this URL: http://perl.4pro.net
+
+=item *
+
+More practical topics are probably discussed in the mailing list at this URL: http://lists.sourceforge.net/lists/listinfo/cgi-builder-users
+
+=back
+
 =head1 PROPERTY ACCESSORS
 
 This module adds just one property to the standard C<CGI::Builder> properties.
@@ -255,19 +284,19 @@ This module adds just one property to the standard C<CGI::Builder> properties.
 
 This property allows you to access the request Apache object.
 
-=head1 CBF overridden methods
+=head1 CBF overridden properties
 
-=head2 page_content_check
- 
-This extension overrides this method just changing the '204 No Content' that the CBF sets when no page_content has been produced by the process, with a more consistent '404 Not Found' status. It does so because the client is requesting a simple not found page, which is a very different situation from a found CGI script that does not send any content (204 No Content).
+=head2 no_page_content_status
 
-B<Note>: You don't need to directly use this method since it's internally called at the very start of the RESPONSE phase. You don't need to override it if you want just to send a different header status, since it sets the status just if it is not defined yet.
+This extension overrides this class property by just changing the '204 No Content' (that the CBF sets when no page_content has been produced by the process), with a more consistent '404 Not Found' status. It does so because the client is requesting a simple not found page, which is a very different situation from a found CGI script that does not send any content (204 No Content).
 
-=head1 SUPPORT and FEEDBACK
+=head1 SUPPORT
+
+Support for all the modules of the CBF is via the mailing list. The list is used for general support on the use of the CBF, announcements, bug reports, patches, suggestions for improvements or new features. The API to the CBF is stable, but if you use the CBF in a production environment, it's probably a good idea to keep a watch on the list.
 
 You can join the CBF mailing list at this url:
 
-    http://lists.sourceforge.net/lists/listinfo/cgi-builder-users
+http://lists.sourceforge.net/lists/listinfo/cgi-builder-users
 
 =head1 AUTHOR and COPYRIGHT
 
